%bcond_with tests

%define major     %{version}
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:           flatbuffers
Version:        25.2.10
Release:        %mkrel 1
Summary:        Memory efficient serialization library
URL:            https://google.github.io/flatbuffers
Group:          Development/Other

# The entire source code is ASL 2.0 except grpc/ which is BSD (3 clause)
License:        ASL 2.0 and BSD

Source0:        https://github.com/google/flatbuffers/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        flatc.1
Source2:        flatbuffers.7

BuildRequires:  cmake
BuildRequires:  git-core
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel

# The library contains pieces of gRPC project, with some additions.
# It is not easy to identify the version, which was used to take the code,
# but it should be something after version 1.3.2. See this discussion for
# details: https://github.com/google/flatbuffers/pull/4305
Provides:       bundled(grpc) = 1.49.0

%description
FlatBuffers is a serialization library for games and other memory constrained
apps. FlatBuffers allows you to directly access serialized data without
unpacking/parsing it first, while still having great forwards/backwards
compatibility.

#------------------------------------------------

%package -n     %{libname}
Summary:        Memory efficient serialization library
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}

%description -n %{libname}
FlatBuffers is a serialization library for games and other memory constrained
apps. FlatBuffers allows you to directly access serialized data without
unpacking/parsing it first, while still having great forwards/backwards
compatibility.

#------------------------------------------------

%package -n     %{develname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
Header files for development with %{name}.

#------------------------------------------------

%package -n     python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Python
BuildArch:      noarch
Requires:       %{name} >= %{version}-%{release}

%description -n python3-%{name}
This package contains python 3 bindings for %{name}.

#------------------------------------------------

%prep
%autosetup -p1
# cleanup distribution
rm -rf js net php docs go java js biicode {samples/,}android

%build
%cmake -DCMAKE_BUILD_TYPE=Release \
       -DFLATBUFFERS_BUILD_SHAREDLIB=ON \
       -DFLATBUFFERS_BUILD_FLATLIB=OFF \
       -DFLATBUFFERS_BUILD_FLATC=ON \
       -DFLATBUFFERS_BUILD_TESTS=%{?with_tests:ON}%{!?with_tests:OFF}

%cmake_build

pushd python
%pyproject_wheel
popd

%install
%cmake_install

pushd python
%pyproject_install
%pyproject_save_files flatbuffers
popd

mkdir -p %{buildroot}%{_mandir}/man{1,7}
cp -p %{SOURCE1} %{buildroot}%{_mandir}/man1/flatc.1
cp -p %{SOURCE2} %{buildroot}%{_mandir}/man7/flatbuffers.7

%check
%if %{with tests}
%__make test -C %{_vpath_builddir}
%endif

%files
%license LICENSE
%doc README.md
%{_bindir}/flatc
%{_mandir}/man1/flatc.1*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_mandir}/man7/%{name}.7*
%{_libdir}/cmake/%{name}/
%{_libdir}/pkgconfig/%{name}.pc

%files -n python3-%{name} -f %{pyproject_files}
%license LICENSE
%doc README.md


%changelog
* Mon Mar 03 2025 papoteur <papoteur> 25.2.10-1.mga10
+ Revision: 2159360
- new version 25.2.10

* Tue Dec 24 2024 daviddavid <daviddavid> 24.12.23-1.mga10
+ Revision: 2129840
- new version: 24.12.23

* Fri Jun 07 2024 daviddavid <daviddavid> 24.3.25-1.mga10
+ Revision: 2070403
- new version: 24.3.25

* Sun Mar 10 2024 daviddavid <daviddavid> 24.3.6-1.mga10
+ Revision: 2049078
- new version: 24.3.6

* Fri Dec 29 2023 daviddavid <daviddavid> 23.5.26-2.mga10
+ Revision: 2023636
- rebuild for py3.12

* Sun Oct 22 2023 daviddavid <daviddavid> 23.5.26-1.mga10
+ Revision: 2000256
- new version: 23.5.26

* Mon Aug 08 2022 neoclust <neoclust> 2.0.6-1.mga9
+ Revision: 1876081
- New version 2.0.6

* Sat Mar 19 2022 umeabot <umeabot> 2.0.0-3.mga9
+ Revision: 1799271
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 tv <tv> 2.0.0-2.mga9
+ Revision: 1782849
- Rebuild for python-3.10

* Thu Oct 21 2021 joequant <joequant> 2.0.0-1.mga9
+ Revision: 1752461
- update to 2.0.0

* Sat Mar 20 2021 daviddavid <daviddavid> 1.12.0-5.mga9
+ Revision: 1705916
- rebuild for python 3.9

* Mon Aug 10 2020 neoclust <neoclust> 1.12.0-4.mga8
+ Revision: 1613087
- Rebuild because of wrong rpm preventing hdlist generation

* Mon Aug 10 2020 daviddavid <daviddavid> 1.12.0-3.mga8
+ Revision: 1613061
- make python3 sub-pkg noarch

* Mon Aug 10 2020 daviddavid <daviddavid> 1.12.0-2.mga8
+ Revision: 1613047
- enable python3 module

* Tue Jun 23 2020 daviddavid <daviddavid> 1.12.0-1.mga8
+ Revision: 1598873
- new version: 1.12.0
- fix illegal version in CMake/FlatbuffersConfigVersion.cmake.in
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Fri Jul 05 2019 daviddavid <daviddavid> 1.11.0-1.mga8
+ Revision: 1418681
- new version: 1.11.0

* Wed Oct 31 2018 daviddavid <daviddavid> 1.10.0-1.mga7
+ Revision: 1326822
- new version: 1.10.0

* Sun Sep 23 2018 umeabot <umeabot> 1.9.0-4.mga7
+ Revision: 1297719
- Mageia 7 Mass Rebuild

* Mon Aug 20 2018 daviddavid <daviddavid> 1.9.0-3.mga7
+ Revision: 1253010
- libify lib and devel sub-pkgs

* Sun Aug 19 2018 neoclust <neoclust> 1.9.0-2.mga7
+ Revision: 1252882
- imported package flatbuffers


* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Apr 06 2018 Sergey Avseyev <sergey.avseyev@gmail.com> - 1.9.0-1
- Update to 1.9.0

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sat Feb 03 2018 Sergey Avseyev <sergey.avseyev@gmail.com> - 1.8.0-3
- Fix build errors.

* Wed Nov 22 2017 Sergey Avseyev <sergey.avseyev@gmail.com> - 1.8.0-2
- Update manpages for 1.8.0

* Wed Nov 22 2017 Sergey Avseyev <sergey.avseyev@gmail.com> - 1.8.0-1
- Update to 1.8.0

* Thu Nov 2 2017 Sergey Avseyev <sergey.avseyev@gmail.com> - 1.7.1-1
- Initial version

* Mon Mar 30 2015 Daniel Vrátil <dvratil@redhat.com> - 1.0.3-1
- Initial version (abandoned at #1207208)
